@@ -25,7 +25,7 @@ def review(card):
 
 	grade = GRADE_DICT[key] if key in GRADE_DICT else 'exit'
 
-	card.add_history(TODAY, elapsed_time, grade)
+	card.add_history(TODAY, elapsed, grade)
 
 def make_string(card):
 	m = importlib.import_module('.'+card.reviewer, package = 'vinca.reviewers')
